summaryrefslogtreecommitdiff
path: root/lib/diagnostics.pm
diff options
context:
space:
mode:
Diffstat (limited to 'lib/diagnostics.pm')
-rwxr-xr-xlib/diagnostics.pm10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/diagnostics.pm b/lib/diagnostics.pm
index 648ea1281b..1f3f30c1c0 100755
--- a/lib/diagnostics.pm
+++ b/lib/diagnostics.pm
@@ -4,7 +4,7 @@ package diagnostics;
diagnostics - Perl compiler pragma to force verbose warning diagnostics
-splain - stand-alone program to do the same thing
+splain - standalone program to do the same thing
=head1 SYNOPSIS
@@ -41,9 +41,9 @@ that this I<does> enable perl's B<-w> flag.) Your whole
compilation will then be subject(ed :-) to the enhanced diagnostics.
These still go out B<STDERR>.
-Due to the interaction between runtime and compile time issues,
+Due to the interaction between runtime and compiletime issues,
and because it's probably not a very good idea anyway,
-you may not use C<no diagnostics> to turn them off at compile time.
+you may not use C<no diagnostics> to turn them off at compiletime.
However, you may control there behaviour at runtime using the
disable() and enable() methods to turn them off and on respectively.
@@ -66,7 +66,7 @@ Output from I<splain> is directed to B<STDOUT>, unlike the pragma.
=head1 EXAMPLES
The following file is certain to trigger a few errors at both
-runtime and compile time:
+runtime and compiletime:
use diagnostics;
print NOWHERE "nothing\n";
@@ -526,7 +526,7 @@ sub shorten {
}
# have to do this: RS isn't set until run time, but we're executing at compile time
$RS = "\n";
1 unless $standalone; # or it'll complain about itself
@@ -526,7 +526,7 @@ sub shorten {
}
-# have to do this: RS isn't set until run time, but we're executing at compile time
+# have to do this: RS isn't set until run time, but we're executing at compiletime
$RS = "\n";
1 unless $standalone; # or it'll complain about itself